--[[
	Title: Buddy Window
	Author: Skyraker
	Description: Simple window informing player of status changes to friends and guildies
]]--

----------------------------- ADDON LOCALS -----------------------	
local EM = EVENT_MANAGER
local LMP = LibStub:GetLibrary("LibMediaProvider-1.0")
local LAM = LibStub:GetLibrary("LibAddonMenu-1.0")
local newFont = LMP:Register('font',"DejaVu Sans Mono", "MyStatusWindow/dejavusansmono.ttf")
local fontList = LMP:List('font')
local fontStyles = {"normal", "outline", "thick-outline", "shadow", "soft-shadow-thick", "soft-shadow-thin"}
local BWSavedVars = BWSavedVars or {}
---------------------------------------------------------------------

------------------------ SETTINGS WINDOW FUNCTION --------------------------------------------
local function handleMessage(message)
	CHAT_SYSTEM:AddMessage(message,184,20,217,1)
end


-------------------------------------------------------------------------------------------

-------------------------------------- EVENT HANDLER FUNCTIONS --------------------------------------

local function friendLeveled(code,acct,char,level)
	if BWSavedVars.friends.leveled then
		local strippedChar = char:gsub("%^%a+","")
		local message = strippedChar.."("..acct..") is now level "..level
		PlaySound(BWSavedVars.sounds.fLevel)
		handleMessage(message)
	end
end

local function friendStatus(code,acct,preStat,curStat)
	if BWSavedVars.friends.logged then
		local message = ""
		if ((curStat == 1) and ((preStat == 2) or (preStat == 3))) then message = acct.." is available."
		elseif ((curStat == 1) and (preStat == 4)) then message = acct.." has come online."
		elseif (curStat == 2) then message = acct.." is away from the keyboard."
		elseif (curStat == 3) then message = acct.." does not wish to be disturbed."
		elseif (curStat == 4) then message = acct.." has gone offline."
		end
		PlaySound(BWSavedVars.sounds.fStat)
		handleMessage(message)
	end
end

local function friendZoned(code,acct,char,zone)
	if BWSavedVars.friends.zoned then
		local strippedChar = char:gsub("%^%a+","")
		PlaySound(BWSavedVars.sounds.fZone)
		local message = strippedChar.."("..acct..") has entered "..zone
		handleMessage(message)
	end
end

local function friendUpdated(code,acct)
	if BWSavedVars.friends.changed then
		local friendChar = ""
		for _, info in ipairs(FRIENDS_LIST.list.data) do
			if info.data.displayName == acct then
				friendChar = info.data.characterName
			end
		end
		local message = acct .. " has logged in as " .. friendChar
		PlaySound(BWSavedVars.sounds.fChange)
		handleMessage(message)
	end
end

local function guildMemStatus(code,id,acct,preStat,curStat)
	if BWSavedVars.guilds.logged then
		local accountName = GetDisplayName()
		if (acct ~= accountName) then
			local message = ""
			local guildName = GetGuildName(id)
			if ((curStat == 1) and ((preStat == 2) or (preStat == 3))) then message = guildName..": "..acct.." is available."
			elseif ((curStat == 1) and (preStat == 4)) then message = guildName..": "..acct.." has come online."
			elseif (curStat == 2) then message = guildName..": "..acct.." is away from the keyboard."
			elseif (curStat == 3) then message = guildName..": "..acct.." does not wish to be disturbed."
			elseif (curStat == 4) then message = guildName..": "..acct.." has gone offline."
			end
			PlaySound(BWSavedVars.sounds.gStat)
			handleMessage(message)
		end
	end
end

local function guildMemZoned(code,id,acct,char,zone)
	if BWSavedVars.guilds.zoned then
		local accountName = GetDisplayName()
		if (acct ~= accountName) then
			local accountName = GetDisplayName()
			if (acct ~= accountName) then
				local guildName = GetGuildName(id)
				local strippedChar = char:gsub("%^%a+","")
				local message = guildName..": "..strippedChar.." ("..acct..") has entered "..zone
				PlaySound(BWSavedVars.sounds.gZone)
				handleMessage(message)
			end
		end
	end
end

local function guildMemUpdated(code,id,acct)
	if BWSavedVars.guilds.changed then
		local accountName = GetDisplayName()
		if (acct ~= accountName) then
			local message = ""
			local guildName = GetGuildName(id)
			for num = 1, GetNumGuildMembers(id) do
				local name,note,rank,stat,sec = GetGuildMemberInfo(id, num)
				if name == acct then 
					local hasChar,charName,zone,class,alliance,level,vetRank = GetGuildMemberCharacterInfo(id,num)
					local thisChar = charName:gsub("%^%a+","")
					message = guildName..": "..name.." has logged in as "..thisChar
				end
			end
			PlaySound(BWSavedVars.sounds.gChange)
			handleMessage(message)
		end
	end
end

local function guildMemRank(code,id,acct,three)
	if BWSavedVars.guilds.ranked then
		local accountName = GetDisplayName()
		local guildName = GetGuildName(id)
		if (acct ~= accountName) then
			if(three == 1) then testThree = "Guild Master" end
			if(three == 2) then testThree = "Officer" end
			if(three == 3) then testThree = "Member" end
			if(three == 4) then testThree = "Recruit" end
			if(GetGuildRankCustomName(id, three) ~= "") then testThree = GetGuildRankCustomName(id, three) end
			local message = guildName..": "..acct.." is now a(n) "..testThree
			PlaySound(BWSavedVars.sounds.gRank)
			handleMessage(message)
		end
	end
end

local function guildMemLeveled(code,id,acct,char,level)
	if BWSavedVars.guilds.leveled then
		local accountName = GetDisplayName()
		if (acct ~= accountName) then
			local guildName = GetGuildName(id)
			local strippedChar = char:gsub("%^%a+","")
			local message = guildName..": "..strippedChar.."("..acct..") is now level "..level
			PlaySound(BWSavedVars.sounds.gLevel)
			handleMessage(message)
		end
	end
end
---------------------------------------------------------------------------------------------------

-------------------------------------- WINDOW SETTINGS FUNCTIONS ----------------------------------
function BuddyWindow.fade()
	BWSavedVars.offset.X = math.floor(BuddyWindowCont:GetLeft())
	BWSavedVars.offset.Y = math.floor(BuddyWindowCont:GetTop())
	BuddyWindowBG:SetHidden( true )
	BuddyWindow_TB:SetScrollPosition(0)
end

function BuddyWindow.unfade()
	BuddyWindowBG:SetHidden( false )
	BuddyWindow_TB:ShowFadedLines()	
end

function BuddyWindow.showResize()
	BuddyWindow_MoveBG:SetHidden( false )
end

function BuddyWindow.hideResize()
	BuddyWindow_MoveBG:SetHidden( true )
end

-------------------------------------------------------------------------------------------------

-------------------------------------------- INITIALIZATION FUNCTIONS ---------------------------------------
local function registerFriendEvents()
	EM:RegisterForEvent("BuddyWindow",EVENT_FRIEND_CHARACTER_LEVEL_CHANGED,friendLeveled)
	EM:RegisterForEvent("BuddyWindow",EVENT_FRIEND_PLAYER_STATUS_CHANGED,friendStatus)
	EM:RegisterForEvent("BuddyWindow",EVENT_FRIEND_CHARACTER_ZONE_CHANGED,friendZoned)
	EM:RegisterForEvent("BuddyWindow",EVENT_FRIEND_CHARACTER_UPDATED,friendUpdated)
	EM:RegisterForEvent("BuddyWindow",EVENT_GUILD_MEMBER_CHARACTER_UPDATED,guildMemUpdated)
	EM:RegisterForEvent("BuddyWindow",EVENT_GUILD_MEMBER_CHARACTER_ZONE_CHANGED,guildMemZoned)
	EM:RegisterForEvent("BuddyWindow",EVENT_GUILD_MEMBER_RANK_CHANGED,guildMemRank)
	EM:RegisterForEvent("BuddyWindow",EVENT_GUILD_MEMBER_PLAYER_STATUS_CHANGED,guildMemStatus)
	EM:RegisterForEvent("BuddyWindow",EVENT_GUILD_MEMBER_CHARACTER_LEVEL_CHANGED,guildMemLeveled)
end

function BuddyWindow.init(code,name)
	if (name ~= "BuddyWindow") then return; end
	EM:UnregisterForEvent("BuddyWindow",code)
	BWSavedVars = BuddyWindow.setupSavedVars()
	registerFriendEvents()
	BuddyWindowCont:ClearAnchors()
	BuddyWindowCont:SetAnchor(TOPLEFT,GuiXml,TOPLEFT,BWSavedVars.offset.X,BWSavedVars.offset.Y)
	BuddyWindowBG:SetAlpha(BWSavedVars.alpha)
	BuddyWindow_TB:SetLineFade(8,3)
	BuddyWindow_TB:SetFont(("%s|%s|%s"):format(LMP:Fetch('font', BWSavedVars.font), BWSavedVars.size, BWSavedVars.style))
end
--------------------------------------------------------------------------------------------------------

---------------------------------------------- ADDON START EVENT ----------------------------------------
EM:RegisterForEvent("BuddyWindow",EVENT_ADD_ON_LOADED,BuddyWindow.init)
--------------------------------------------------------------------------------------------------------