local LAM2 = LibStub:GetLibrary("LibAddonMenu-2.0")
local LMP = LibStub:GetLibrary("LibMediaProvider-1.0")
local newFont = LMP:Register('font',"DejaVu Sans Mono", "MyStatusWindow/dejavusansmono.ttf")
local fontList = LMP:List('font')
local fontStyles = {"normal", "outline", "thick-outline", "shadow", "soft-shadow-thick", "soft-shadow-thin"}
local WM = WINDOW_MANAGER
local EM = EVENT_MANAGER
local BWSavedVars = BWSavedVars or {}

--------------------------------------------------------------------------
local panelData = {
	type = "panel",
	name = "Buddy Window",
	author = "Skyraker",
	version = "1.0",
	slashCommand = "/budwin"
}

local optionsData = {
	[1] = {
		type = "header",
		name = "Sounds"
	},
	[2] = {
		type = "dropdown",
		name = "Friend Levels",
		tooltip = "Select sound to play when a friend's character levels up.",
		choices = BuddyWindow.sounds,
		getFunc = function() return BWSavedVars.sounds.fLevel end,
		setFunc = function(value)
								BWSavedVars.sounds.fLevel = value
								PlaySound(value)
							end,
		width = "half"
	},
	[3] = {
		type = "dropdown",
		name = "Friend Zones",
		tooltip = "Select sound to play when a friend's character changes zones.",
		choices = BuddyWindow.sounds,
		getFunc = function() return BWSavedVars.sounds.fZone end,
		setFunc = function(value)
								BWSavedVars.sounds.fZone = value
								PlaySound(value)
							end,
		width = "half"
	},
	[4] = {
		type = "dropdown",
		name = "Friend Status Change",
		tooltip = "Select sound to play when friend's status changes.",
		choices = BuddyWindow.sounds,
		getFunc = function() return BWSavedVars.sounds.fStat end,
		setFunc = function(value)
								BWSavedVars.sounds.fStat = value
								PlaySound(value)
							end,
		width = "half"
	},
	[5] = {
		type = "dropdown",
		name = "Friend Char Change",
		tooltip = "Select sound to play when friends change characters.",
		choices = BuddyWindow.sounds,
		getFunc = function() return BWSavedVars.sounds.fChange end,
		setFunc = function(value)
								BWSavedVars.sounds.fChange = value
								PlaySound(value)
							end,
		width = "half"
	},
	[6] = {
		type = "dropdown",
		name = "Guildmate Levels",
		tooltip = "Select sound to play when guildmates level.",
		choices = BuddyWindow.sounds,
		getFunc = function() return BWSavedVars.sounds.gLevel end,
		setFunc = function(value)
								BWSavedVars.sounds.gLevel = value
								PlaySound(value)
							end,
		width = "half"
	},
	[7] = {
		type = "dropdown",
		name = "Guildmate Zones",
		tooltip = "Select sound to play when guildmates change zones.",
		choices = BuddyWindow.sounds,
		getFunc = function() return BWSavedVars.sounds.gZone end,
		setFunc = function (value)
								BWSavedVars.sounds.gZone = value
								PlaySound(value)
							end,
		width = "half"
	},
	[8] = {
		type = "dropdown",
		name = "Guildmate Status Change",
		tooltip = "Select sound to play when guildmate's status changes.",
		choices = BuddyWindow.sounds,
		getFunc = function() return BWSavedVars.sounds.gStat end,
		setFunc = function (value)
								BWSavedVars.sounds.gStat = value
								PlaySound(value)
							end,
		width = "half"
	},
	[9] = {
		type = "dropdown",
		name = "Guildmate Char Change",
		tooltip = "Select sound to play when guildmates change characters.",
		choices = BuddyWindow.sounds,
		getFunc = function() return BWSavedVars.sounds.gChange end,
		setFunc = function (value)
								BWSavedVars.sounds.gChange = value
								PlaySound(value)
							end,
		width = "half"
	},
	[10] = {
		type = "dropdown",
		name = "Guildmate Rank Change",
		tooltip = "Select sound to play when guildmates change rank.",
		choices = BuddyWindow.sounds,
		getFunc = function() return BWSavedVars.sounds.gRank end,
		setFunc = function (value)
								BWSavedVars.sounds.gRank = value
								PlaySound(value)
							end,
		width = "half"
	},
	[11] = {
		type = "header",
		name = "Text/Transparency Settings"
	},
	[12] = {
		type = "dropdown",
		name = "Font",
		tooltip = "Change displayed font.",
		choices = fontList,
		getFunc = function() return BWSavedVars.font end,
		setFunc = function(value)
								BWSavedVars.font = value
								BuddyWindow_TB:SetFont(("%s|%s|%s"):format(LMP:Fetch('font',BWSavedVars.font), BWSavedVars.size,BWSavedVars.style))
							end,
		width = "half"
	},
	[13] = {
		type = "slider",
		name = "Size",
		tooltip = "Change font size.",
		min = 10,
		max = 20,
		step = 2,
		getFunc = function() return BWSavedVars.size end,
		setFunc = function(value)
								BWSavedVars.size = value
								BuddyWindow_TB:SetFont(("%s|%s|%s"):format(LMP:Fetch('font', BWSavedVars.font), BWSavedVars.size, BWSavedVars.style))
							end,
		width = "half"
	},
	[14] = {
		type = "dropdown",
		name = "Style",
		tooltip = "Change font style.",
		choices = fontStyles,
		getFunc = function() return BWSavedVars.style end,
		setFunc = function(value)
								BWSavedVars.style = value
								BuddyWindow_TB:SetFont(("%s|%s|%s"):format(LMP:Fetch('font', BWSavedVars.font), BWSavedVars.size, BWSavedVars.style))
							end,
		width = "half"
	},
	[15] = {
		type = "header",
		name = "Friend Display Settings"
	},
	[16] = {
		type = "checkbox",
		name = "Toggle All Friend Updates",
		tooltip = "Toggle display of all friend updates.",
		getFunc = function() return BWSavedVars.friends.all end,
		setFunc = function(value)
								BWSavedVars.friends.all = not BWSavedVars.friends.all
								BWSavedVars.friends.logged = not BWSavedVars.friends.logged
								BWSavedVars.friends.leveled = not BWSavedVars.friends.leveled
								BWSavedVars.friends.changed = not BWSavedVars.friends.changed
								BWSavedVars.friends.zoned = not BWSavedVars.friends.zoned
							end,
		width = "half"
	},
	[17] = {
		type = "checkbox",
		name = "Login/Logout",
		tooltip = "Toggle display of friends logging in or out.",
		getFunc = function() return BWSavedVars.friends.logged end,
		setFunc = function(value)
								BWSavedVars.friends.logged = not BWSavedVars.friends.logged
							end,
		width = "half"
	},
	[18] = {
		type = "checkbox",
		name = "Leveling",
		tooltip = "Toggle display of friends' characters leveling.",
		getFunc = function() return BWSavedVars.friends.leveled end,
		setFunc = function(value)
								BWSavedVars.friends.leveled = not BWSavedVars.friends.leveled
							end,
		width = "half"
	},
	[19] = {
		type = "checkbox",
		name = "Zone Changes",
		tooltip = "Toggle display of friends' characters changing zones.",
		getFunc = function() return BWSavedVars.friends.zoned end,
		setFunc = function(value)
								BWSavedVars.friends.zoned = not BWSavedVars.friends.zoned
							end,
		width = "half"
	},
	[20] = {
		type = "checkbox",
		name = "Char Changes",
		tooltip = "Toggle display of friends changing active character.",
		getFunc = function() return BWSavedVars.friends.changed end,
		setFunc = function(value)
								BWSavedVars.friends.changed = not BWSavedVars.friends.changed
							end,
		width = "half"
	},
	[21] = {
		type = "header",
		name = "Guild Display Settings"
	},
	[22] = {
		type = "checkbox",
		name = "Toggle all guild updates",
		tooltip = "Toggle display of all guild updates.",
		getFunc = function() return BWSavedVars.guilds.all end,
		setFunc = function (value)
								BWSavedVars.guilds.all = not BWSavedVars.guilds.all
								BWSavedVars.guilds.logged = not BWSavedVars.guilds.logged
								BWSavedVars.guilds.leveled = not BWSavedVars.guilds.leveled
								BWSavedVars.guilds.zoned = not BWSavedVars.guilds.zoned
								BWSavedVars.guilds.changed = not BWSavedVars.guilds.changed
								BWSavedVars.guilds.ranked = not BWSavedVars.guilds.ranked
							end,
		half = "half"
	},
	[23] = {
		type = "checkbox",
		name = "Login/Logout",
		tooltip = "Toggle display of guild members logging in or out.",
		getFunc = function() return BWSavedVars.guilds.logged end,
		setFunc = function(value)
								BWSavedVars.guilds.logged = not BWSavedVars.guilds.logged
							end,
		width = "half"
	},
	[24] = {
		type = "checkbox",
		name = "Leveling",
		tooltip = "Toggle display of guild members' characters leveling.",
		getFunc = function() return BWSavedVars.guilds.leveled end,
		setFunc = function(value)
								BWSavedVars.guilds.leveled = not BWSavedVars.guilds.leveled
							end,
		width = "half"
	},
	[25] = {
		type = "checkbox",
		name = "Zone Change",
		tooltip = "Toggle display of guild members' characters changing zones.",
		getFunc = function() return BWSavedVars.guilds.zoned end,
		setFunc = function(value)
								BWSavedVars.guilds.zoned = not BWSavedVars.guilds.zoned
							end,
		width = "half"
	},
	[26] = {
		type = "checkbox",
		name = "Char Change",
		tooltip = "Toggle display of guild members changing active characters.",
		getFunc = function() return BWSavedVars.guilds.changed end,
		setFunc = function(value)
								BWSavedVars.guilds.changed = not BWSavedVars.guilds.changed
							end,
		width = "half"
	},
	[27] = {
		type = "checkbox",
		name = "Guild Rank",
		tooltip = "Toggle display of guild members changing rank.",
		getFunc = function() return BWSavedVars.guilds.ranked end,
		setFunc = function(value)
								BWSavedVars.guilds.ranked = not BWSavedVars.guilds.ranked
							end,
		width = "half"
	}
}

-----------------------------------------------------------

----------------------------------------------------------
LAM2:RegisterAddonPanel("BWOptions", panelData)
LAM2:RegisterOptionControls("BWOptions", optionsData)
-----------------------------------------------------------

local function Init(code, name)
	if name == "BuddyWindow" then
		EM:UnregisterForEvent("BW_Settings",code)
		BWSavedVars = BuddyWindow.setupSavedVars()
	end
end

EM:RegisterForEvent( "BW_Settings" , EVENT_ADD_ON_LOADED , Init )